Module format_integer

Module format_integer 

format_integer_str, a function for formatting an Integer according to a GMP-style printf format string.

Functions

format_integer_str
Formats an Integer according to a GMP-style printf format string, for strict compatibility with GMP’s gmp_printf family.