RandomIntegerPolynomialsFromIntegers

Type Alias RandomIntegerPolynomialsFromIntegers 

pub type RandomIntegerPolynomialsFromIntegers = RandomIntegerPolynomials<GeometricRandomNaturalValues<u64>, RandomPolynomialCoefficients, RandomPolynomialLeadingCoefficients>;
The type of the IntegerPolynomial generators that draw their coefficients from every Integer and their leading coefficients from every nonzero one, with lengths from a geometric distribution.

Aliased Type

pub struct RandomIntegerPolynomialsFromIntegers(/* private fields */);